<a id="packages.valory.skills.oracle_abci.models"></a>

# packages.valory.skills.oracle`_`abci.models

This module contains the shared state for the price estimation app ABCI application.

<a id="packages.valory.skills.oracle_abci.models.SharedState"></a>

## SharedState Objects

```python
class SharedState(BaseSharedState)
```

Keep the current shared state of the skill.

<a id="packages.valory.skills.oracle_abci.models.SharedState.__init__"></a>

#### `__`init`__`

```python
def __init__(*args: Any, **kwargs: Any) -> None
```

Initialize the state.

<a id="packages.valory.skills.oracle_abci.models.SharedState.setup"></a>

#### setup

```python
def setup() -> None
```

Set up.

